@@ -70,7 +70,7 @@ void FavoriteListView::update()
 
         KListViewItem* item = new KListViewItem( subjectList );
         item->setText( Col_Board, thread->boardName() );
-        item->setText( Col_Subject, thread->name() );
+        item->setText( Col_Subject, Kita::unescape( thread->name() ) );
         item->setText( Col_Read, QString( "%1" ).arg( readNum, 4 ) );
         if ( resNum > 0 ) {
             item->setText( Col_ResNum, QString( "%1" ).arg( resNum, 4 ) );
