@@ -100,9 +100,6 @@ KitaMainWindow::KitaMainWindow()
     connect( m_subjectView, SIGNAL( signalShowThreadWithNewTab( const Kita::Thread* ) ),
              m_threadView, SLOT( showThreadWithNewTab( const Kita::Thread* ) ) );
 
-    connect( m_threadView, SIGNAL( thread( const Kita::Thread* ) ),
-             SLOT( updateThreadCache( const Kita::Thread* ) ) );
-
     connect( m_threadView, SIGNAL( thread( const Kita::Thread* ) ),
              m_subjectView, SLOT( updateThread( const Kita::Thread* ) ) );
 
@@ -219,7 +216,7 @@ void KitaMainWindow::setupActions()
                        i18n( "URL Line" ),
                        0,
                        this,
-                       SLOT( slotUrlLine() )      /* dummy */,
+                       SLOT( slotUrlLine() )       /* dummy */,
                        actionCollection(), "url_line_action" );
 
     KStdAction::keyBindings( this, SLOT( optionsConfigureKeys() ), actionCollection() );
@@ -497,12 +494,6 @@ void KitaMainWindow::slotOpenURLRequest( const KURL& url, const KParts::URLArgs&
     new KRun( url );
 }
 
-void KitaMainWindow::updateThreadCache( const Kita::Thread* thread )
-{
-    KitaThreadInfo::setReadNum( thread->datURL(), thread->resNum() );
-    KitaThreadInfo::setResNum( thread->datURL(), thread->resNum() );
-}
-
 void KitaMainWindow::loadCache()
 {
     KitaThreadInfo * cache = KitaThreadInfo::getInstance();
