@@ -81,8 +81,6 @@ void KitaSubjectView::loadThread( QListViewItem* item )
 
     KURL datURL = item->text( Col_DatURL );
 
-    Kita::Board::setName( Kita::datToBoard( datURL.url() ), m_board->name() );
-    Kita::Thread::setName( datURL.url(), item->text( Col_Subject ) );
     Kita::Thread* thread = Kita::Thread::getByURL( datURL.url() );
 
     emit signalShowThread( thread );
@@ -120,7 +118,7 @@ void KitaSubjectView::loadBoard( const Kita::Board* board )
 
         Kita::ThreadListViewItem* item = new Kita::ThreadListViewItem( subjectList );
         item->setText( Col_ID, QString( "%1" ).arg( i + 1, 4 ) );
-        item->setText( Col_Subject, thread->name() );
+        item->setText( Col_Subject, Kita::unescape( thread->name() ) );
         item->setText( Col_ResNum, QString( "%1" ).arg( resNum, 4 ) );
         item->setText( Col_Read, ( readNum > 0 ) ? QString( "%1" ).arg( readNum, 4 ) : QString( "" ) );
         item->setText( Col_Unread, ( readNum > 0 && resNum != readNum ) ? QString( "%1" ).arg( resNum - readNum, 4 ) : QString( "" ) );
