@@ -23,6 +23,8 @@
 #include <qmessagebox.h>
 #include <qregexp.h>
 
+#include "libkita/kita_misc.h"
+
 #define MAX_TABLABEL_LEN 20
 
 KitaThreadTabWidget::KitaThreadTabWidget( QWidget* parent, const char* name, WFlags f )
@@ -50,7 +52,7 @@ void KitaThreadTabWidget::showThread( const Kita::Thread* thread )
     static_cast<KitaThreadView *>( currentPage() ) ->showThread( thread );
 
     // FIXME: showThreadWithNewTab()إԡ
-    setTabLabel( currentPage(), thread->name().left( MAX_TABLABEL_LEN ) );
+    setTabLabel( currentPage(), Kita::unescape( thread->name().left( MAX_TABLABEL_LEN ) ) );
     setTabToolTip( currentPage(), thread->name() );
 }
 
@@ -84,7 +86,7 @@ void KitaThreadTabWidget::showThreadWithNewTab( const Kita::Thread* thread )
     KitaThreadView * view = createView();
 
     if ( view ) {
-        addTab( view, thread->name().left( MAX_TABLABEL_LEN ) );
+        addTab( view, Kita::unescape( thread->name().left( MAX_TABLABEL_LEN ) ) );
         setTabToolTip( view, thread->name() );
 
         connectSignals( view );
@@ -94,7 +96,7 @@ void KitaThreadTabWidget::showThreadWithNewTab( const Kita::Thread* thread )
         QString threadName = view->threadName();
 
         // FIXME: showThread()饳ԡ
-        setTabLabel( currentPage(), threadName.left( MAX_TABLABEL_LEN ) );
+        setTabLabel( currentPage(), Kita::unescape( threadName.left( MAX_TABLABEL_LEN ) ) );
         setTabToolTip( currentPage(), threadName );
     }
 }
