@@ -12,6 +12,8 @@
 
 #include <kdebug.h>
 
+#include <qstylesheet.h>
+
 #include "threadinfo.h"
 
 FavoriteThreads* FavoriteThreads::instance = 0;
@@ -158,7 +160,7 @@ bool FavoritesXmlParser::endElement( const QString& namespaceURI, const QString&
         m_inThread = false;
         m_threadParser->endElement( namespaceURI, localName, qName );
         Kita::Thread* thread = m_threadParser->getThread();
-        Kita::Thread::setName( thread->datURL(), thread->name() );
+        Kita::Thread::setName( thread->datURL(), QStyleSheet::escape( thread->name() ) );
         m_threadList.append( Kita::Thread::getByURL( thread->datURL() ) );
         KitaThreadInfo::setResNum( thread->datURL(), thread->resNum() );
 
