@@ -112,3 +112,17 @@ QString Kita::datToCache( const QString& datURL )
 
     return QString( "%1/%2/%3" ).arg( host ).arg( board ).arg( filename );
 }
+
+QString Kita::httpToK2ch( const QString& httpURL )
+{
+    KURL url( httpURL );
+    url.setProtocol( "k2ch" );
+
+    return url.url();
+}
+
+QString Kita::unescape( const QString& str )
+{
+    QString ret = str;
+    return ret.replace( "&lt;", "<" ).replace( "&gt;", ">" ).replace( "&amp;", "&" );
+}
