@@ -25,7 +25,7 @@ class BoardTest : public CppUnit::TestFixture {
     CPPUNIT_TEST_SUITE_END();
 
     Kita::Board *m_normal, *m_share1, *m_share2, *m_share3, *m_null;
-    Kita::Board m_fromxml, m_fromxml2; // FIXME: should use pointer.
+    Kita::Board *m_fromxml, *m_fromxml2;
 public:
     void setUp();
     void tearDown();
