@@ -89,25 +89,25 @@ void CommentTest::testToHtml()
                         "<b><a href=\"mailto:mail\" title=\"mail\">name</a></b> "
                         "2003/11/03 00:39 ID:abcdefgh</dt>"
                         "<dd>comment<br/><br/></dd></dl>"),
-                        m_normal->toHtml( 1 ) );
+                        m_normal->toHtml( 1, false ) );
   CPPUNIT_ASSERT_EQUAL( QString("<dl><dt><span id=\"1\"/>1 "
                         "<b><a href=\"mailto:mail\" title=\"mail\">name</a></b> "
                         "2003/11/03 00:40 ID:12345678</dt>"
                         "<dd>comment<br/><br/></dd></dl>"),
-                        m_normal1->toHtml( 1 ) );
+                        m_normal1->toHtml( 1, false ) );
   CPPUNIT_ASSERT_EQUAL( QString("<dl><dt><span id=\"1\"/>1 "
                         "<b><a href=\"mailto:mail\" title=\"mail\">name</a></b> "
                         "2003/11/03 00:41 ID:abcdefgh</dt>"
                         "<dd>foo <a href=\"http://kita.sourceforge.jp/\">http://kita.sourceforge.jp/</a> bar<br/><br/></dd></dl>"),
-                        m_http->toHtml( 1 ) );
+                        m_http->toHtml( 1, false ) );
   CPPUNIT_ASSERT_EQUAL( QString("<dl><dt><span id=\"1\"/>1 "
                         "<b><a href=\"mailto:mail\" title=\"mail\">name</a></b> "
                         "2003/11/03 00:41 ID:abcdefgh</dt>"
                         "<dd>foo <a href=\"http://kita.sourceforge.jp/\">ttp://kita.sourceforge.jp/</a> bar<br/><br/></dd></dl>"),
-                        m_ttp->toHtml( 1 ) );
+                        m_ttp->toHtml( 1, false ) );
   CPPUNIT_ASSERT_EQUAL( QString("<dl><dt><span id=\"1\"/>1 "
                         "<b><a href=\"mailto:mail\" title=\"mail\">name</a></b> "
                         "2003/11/03 00:42 ID:abcdefgh</dt>"
                         "<dd>foo <a href=\"http://kita.sourceforge.jp:80/index.html\">http://kita.sourceforge.jp:80/index.html</a> bar<br/><br/></dd></dl>"),
-                        m_port->toHtml( 1 ) );
+                        m_port->toHtml( 1, false ) );
 }
