@@ -28,7 +28,7 @@ class CommentTest : public CppUnit::TestFixture
   CPPUNIT_TEST( testToHtml );
   CPPUNIT_TEST_SUITE_END();
 
-  Kita::Comment *m_normal, *m_normal1, *m_http, *m_ttp;
+  Kita::Comment *m_normal, *m_normal1, *m_http, *m_ttp, *m_port;
 
 public:
   void setUp();
