@@ -16,6 +16,8 @@
 #include "commenttest.h"
 #include "threadtest.h"
 #include "boardtest.h"
+#include "misctest.h"
+#include "favoritethreadstest.h"
 
 int main( int argc, char* argv[] )
 {
@@ -26,6 +28,8 @@ int main( int argc, char* argv[] )
   runner.addTest( CommentTest::suite() );
   runner.addTest( ThreadTest::suite() );
   runner.addTest( BoardTest::suite() );
+  runner.addTest( MiscTest::suite() );
+  runner.addTest( FavoriteThreadsTest::suite() );
   runner.run( "" );
   return 0;
 }
