@@ -15,6 +15,8 @@
 #include <qxml.h>
 #include <qdict.h>
 
+#include <stdio.h>
+
 namespace KIO
 {
     class Job;
@@ -97,40 +99,6 @@ namespace Kita
         bool m_isValid;
         bool m_inThread;
     };
-
-    class ThreadAccess : public QObject
-    {
-        Q_OBJECT
-
-    public:
-        ThreadAccess( const Thread* thread ) : m_thread( thread ) {};
-        ~ThreadAccess() {};
-
-        QString get();
-        void killJob();
-        int serverTime();
-
-    private:
-        void enter_loop();
-        QString getCachePath( const KURL& url );
-        char* getCacheData( const KURL& url );
-        void writeCacheData( const KURL& url );
-        int responseCode();
-
-        const Thread* m_thread;
-        KIO::Job* m_currentJob;
-        QCString m_threadData;
-        QString m_header;
-        char* m_orgData;
-
-    private slots:
-        void slotReceiveThreadData( KIO::Job* job, const QByteArray& data );
-        void slotRedirection( KIO::Job* job, const KURL& );
-        void slotThreadResult( KIO::Job* job );
-
-    signals:
-        void redirection( const QString& );
-    };
 };
 
 #endif
