@@ -39,6 +39,7 @@
 #include "kita2ch.h"
 #include "kitaconfig.h"
 
+#include "libkita/access.h"
 #include "libkita/threadinfo.h"
 #include "libkita/comment.h"
 #include "libkita/qcp932codec.h"
@@ -155,7 +156,7 @@ void KitaThreadView::showThread( const Kita::Thread* thread )
 
     m_thread = const_cast<Kita::Thread *>( thread );
 
-    m_access = new Kita::ThreadAccess( thread );
+    m_access = new Kita::Access( thread );
     connect( m_access, SIGNAL( redirection( const QString& ) ),
              SIGNAL( setLocationBarURL( const QString& ) ) );
     QString result = m_access->get();
